# ///////////////////////////////////////
# Random Generation
# ///////////////////////////////////////


FOLDER_DEFAULTS_RANDOM_FOLDER_NAME_WORD_2 = [
    "chillers",
    "smokers",
    "freakers",
    "funkers",
    "hackers",
    "tweakers",
    "greasers",
    "seizuers",
    "leisuers",
    "vibers",
    "pleasers",
    "melters",
    "healers",
    "feelers",
    "breakers",
    "fillers",
    "clearers",
    "tools",
]
